==> ceph-osd-2024.2.212+6b985e51b.tgz: ceph-osd/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency to >= 0.1.0
- 0.1.2 wait for only osd pods from post apply job
- 0.1.3 Search for complete logical volume name for OSD data volumes
- 0.1.4 Don't try to prepare OSD disks that are already deployed
- 0.1.5 Fix the sync issue between osds when using shared disk for metadata
- 0.1.6 Logic improvement for used osd disk detection
- 0.1.7 Synchronization audit for the ceph-volume osd-init script
- 0.1.8 Update post apply job
- 0.1.9 Check inactive PGs multiple times
- 0.1.10 Fix typo in check inactive PGs logic
- 0.1.11 Fix post-apply job failure related to fault tolerance
- 0.1.12 Add a check for misplaced objects to the post-apply job
- 0.1.13 Remove default OSD configuration
- 0.1.14 Alias synchronized commands and fix descriptor leak
- 0.1.15 Correct naming convention for logical volumes in disk_zap()
- 0.1.16 dmsetup remove logical devices using correct device names
- 0.1.17 Fix a bug with DB orphan volume removal
- 0.1.18 Uplift from Nautilus to Octopus release
- 0.1.19 Update rbac api version
- 0.1.20 Update directory-based OSD deployment for image changes
- 0.1.21 Refactor Ceph OSD Init Scripts - First PS
- 0.1.22 Refactor Ceph OSD Init Scripts - Second PS
- 0.1.23 Use full image ref for docker official images
- 0.1.24 Ceph OSD Init Improvements
- 0.1.25 Export crash dumps when Ceph daemons crash
- 0.1.26 Mount /var/crash inside ceph-osd pods
- 0.1.27 Limit Ceph OSD Container Security Contexts
- 0.1.28 Change var crash mount propagation to HostToContainer
- 0.1.29 Fix Ceph checkDNS script
- 0.1.30 Ceph OSD log-runner container should run as ceph user
- 0.1.31 Helm 3 - Fix Job labels
- 0.1.32 Update htk requirements
- 0.1.33 Update log-runner container for MAC
- 0.1.34 Remove wait for misplaced objects during OSD restarts
- 0.1.35 Consolidate mon_endpoints discovery
- 0.1.36 Add OSD device location pre-check
- 0.1.37 Add a disruptive OSD restart to the post-apply job
- 0.1.38 Skip pod wait in post-apply job when disruptive
- 0.1.39 Allow for unconditional OSD restart
- 0.1.40 Remove udev interactions from osd-init
- 0.1.41 Remove ceph-mon dependency in ceph-osd liveness probe
- 0.1.42 Added OCI registry authentication
- 0.1.43 Update all Ceph images to Focal
- 0.1.44 Update Ceph to 17.2.6
- 0.1.45 Extend the ceph-osd post-apply job PG wait
- 0.1.46 Use Helm toolkit functions for Ceph probes
- 0.1.47 Add disk zap to OSD init forced repair case
- 0.1.48 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.49 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.50 Allow lvcreate to wipe existing LV metadata
- 0.1.51 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.52 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.53 Update ceph-daemon to be able to use tini init system
- 0.1.54 Remove use of tini for ceph-daemon
- 0.1.55 Update ceph-osd pod containers to make sure OSD pods are properly terminated at restart
- 0.1.56 Add preStop lifecycle script to log-runner
- 0.1.57 Added code to kill another background process in log-runner at restart
- 0.1.58 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> ceph-osd-2025.1.1+35052e51b.tgz: ceph-osd/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency to >= 0.1.0
- 0.1.2 wait for only osd pods from post apply job
- 0.1.3 Search for complete logical volume name for OSD data volumes
- 0.1.4 Don't try to prepare OSD disks that are already deployed
- 0.1.5 Fix the sync issue between osds when using shared disk for metadata
- 0.1.6 Logic improvement for used osd disk detection
- 0.1.7 Synchronization audit for the ceph-volume osd-init script
- 0.1.8 Update post apply job
- 0.1.9 Check inactive PGs multiple times
- 0.1.10 Fix typo in check inactive PGs logic
- 0.1.11 Fix post-apply job failure related to fault tolerance
- 0.1.12 Add a check for misplaced objects to the post-apply job
- 0.1.13 Remove default OSD configuration
- 0.1.14 Alias synchronized commands and fix descriptor leak
- 0.1.15 Correct naming convention for logical volumes in disk_zap()
- 0.1.16 dmsetup remove logical devices using correct device names
- 0.1.17 Fix a bug with DB orphan volume removal
- 0.1.18 Uplift from Nautilus to Octopus release
- 0.1.19 Update rbac api version
- 0.1.20 Update directory-based OSD deployment for image changes
- 0.1.21 Refactor Ceph OSD Init Scripts - First PS
- 0.1.22 Refactor Ceph OSD Init Scripts - Second PS
- 0.1.23 Use full image ref for docker official images
- 0.1.24 Ceph OSD Init Improvements
- 0.1.25 Export crash dumps when Ceph daemons crash
- 0.1.26 Mount /var/crash inside ceph-osd pods
- 0.1.27 Limit Ceph OSD Container Security Contexts
- 0.1.28 Change var crash mount propagation to HostToContainer
- 0.1.29 Fix Ceph checkDNS script
- 0.1.30 Ceph OSD log-runner container should run as ceph user
- 0.1.31 Helm 3 - Fix Job labels
- 0.1.32 Update htk requirements
- 0.1.33 Update log-runner container for MAC
- 0.1.34 Remove wait for misplaced objects during OSD restarts
- 0.1.35 Consolidate mon_endpoints discovery
- 0.1.36 Add OSD device location pre-check
- 0.1.37 Add a disruptive OSD restart to the post-apply job
- 0.1.38 Skip pod wait in post-apply job when disruptive
- 0.1.39 Allow for unconditional OSD restart
- 0.1.40 Remove udev interactions from osd-init
- 0.1.41 Remove ceph-mon dependency in ceph-osd liveness probe
- 0.1.42 Added OCI registry authentication
- 0.1.43 Update all Ceph images to Focal
- 0.1.44 Update Ceph to 17.2.6
- 0.1.45 Extend the ceph-osd post-apply job PG wait
- 0.1.46 Use Helm toolkit functions for Ceph probes
- 0.1.47 Add disk zap to OSD init forced repair case
- 0.1.48 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.49 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.50 Allow lvcreate to wipe existing LV metadata
- 0.1.51 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.52 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.53 Update ceph-daemon to be able to use tini init system
- 0.1.54 Remove use of tini for ceph-daemon
- 0.1.55 Update ceph-osd pod containers to make sure OSD pods are properly terminated at restart
- 0.1.56 Add preStop lifecycle script to log-runner
- 0.1.57 Added code to kill another background process in log-runner at restart
- 0.1.58 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
